package com.example.api.core.data.core

import com.example.api.core.domain.ApiRepository
import com.example.api.core.domain.AuthUserResponse
import com.example.api.core.domain.FetchResult
import com.example.api.core.domain.RegisterUser
import retrofit2.HttpException
import java.net.UnknownHostException

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

internal class BaseApiRepository(
    private val service: ApiService,
    private val dataStoreRepository: DataStoreRepository
) : RemoteMapper(), ApiRepository {

    override suspend fun auth(registerUser: RegisterUser): FetchResult<AuthUserResponse> {
        return try {
            service.register(registerUser.toRegisterUserDto())
            val response = service.auth(registerUser.toSignInUserDto())
            dataStoreRepository.saveToken(response.token)

            FetchResult.Success(response.toUserResponse())
        } catch (e: UnknownHostException) {
            FetchResult.Error(null, "no internet connection")
        } catch (e: HttpException) {
            FetchResult.Error(null, e.message())
        } catch (e: Exception) {
            FetchResult.Error(null, e.message!!)
        }
    }
}