package com.example.api.core.data.core

import com.example.api.core.data.dto.AuthUserResponseDto
import com.example.api.core.data.dto.RegisterUserDto
import com.example.api.core.data.dto.SignInUserDto
import com.example.api.core.data.dto.SignInUserResponseDto
import com.example.api.core.data.dto.UserResponseDto
import com.example.api.core.domain.AuthUserResponse
import com.example.api.core.domain.RegisterUser
import com.example.api.core.domain.SignInUserResponse
import com.example.api.core.domain.UserResponse

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 27.05.2025
 * */

internal abstract class RemoteMapper {
    protected fun RegisterUser.toRegisterUserDto(): RegisterUserDto {
        return RegisterUserDto(
            email = email,
            password = password,
            passwordConfirm = passwordConfirm
        )
    }

    protected fun RegisterUser.toSignInUserDto(): SignInUserDto {
        return SignInUserDto(
            identity = email,
            password = password
        )
    }

    protected fun AuthUserResponseDto.toUserResponse(): AuthUserResponse {
        return AuthUserResponse(
            record = record.toUserResponse(),
            token = token
        )
    }

    protected fun SignInUserResponseDto.toUserResponse(): SignInUserResponse {
        return SignInUserResponse(
            collectionId = collectionId,
            collectionName = collectionName,
            created = created,
            dateBirthday = dateBirthday,
            emailVisibility = emailVisibility,
            email = email,
            firstname = firstname,
            gender = gender,
            id = id,
            lastname = lastname,
            secondname = secondname,
            updated = updated,
            verified = verified
        )
    }
}